@@ -17,24 +17,24 @@ from ._constants import GRAY2BGR, GRAY2RGB
 from ._bgr import bgr2lab, bgr2hsv, bgr2hls, bgr2yuv, bgr2luv
 
 __all__ = [
-    'gray2rgb',
-    'gray2bgr',
-    'gray2lab',
-    'gray2hsv',
-    'gray2hls',
-    'gray2yuv',
-    'gray2luv',
+    "gray2rgb",
+    "gray2bgr",
+    "gray2lab",
+    "gray2hsv",
+    "gray2hls",
+    "gray2yuv",
+    "gray2luv",
 ]
 
 
-def _is_gray_image(tens):
+def _is_gray_image(tens: Tensor):
     # tens = to_tensor(tens)
     # return tens.is_gray()
     return (len(tens.shape) == 2) or (len(tens.shape) == 3 and tens.shape[-1] == 1)
 
 
-def gray2rgb(tens) -> Tensor:
-    r'''
+def gray2rgb(tens: Tensor) -> Tensor:
+    r"""
         Converts a Grayscale Tensor to its RGB version.
 
     Args:
@@ -46,18 +46,19 @@ def gray2rgb(tens) -> Tensor:
     Raises:
         ValueError: If `tens` is not of shape 2
 
-    '''
+    """
     if not _is_gray_image(tens):
         raise ValueError(
-            f'Tensor of shape 2 expected. Found shape {len(tens.shape)}. This function converts a Grayscale Tensor to its RGB counterpart'
+            f"Tensor of shape 2 expected. Found shape {len(tens.shape)}. "
+            "This function converts a Grayscale Tensor to its RGB counterpart"
         )
 
-    im = cv.cvtColor(tens, GRAY2RGB)
-    return to_tensor(im, cspace='rgb')
+    img = cv.cvtColor(tens, GRAY2RGB)
+    return to_tensor(img, cspace="rgb")
 
 
-def gray2bgr(tens) -> Tensor:
-    r'''
+def gray2bgr(tens: Tensor) -> Tensor:
+    r"""
         Converts a Grayscale Tensor to its BGR version.
 
     Args:
@@ -69,18 +70,19 @@ def gray2bgr(tens) -> Tensor:
     Raises:
         ValueError: If `tens` is not of shape 2
 
-    '''
+    """
     if not _is_gray_image(tens):
         raise ValueError(
-            f'Tensor of shape 2 expected. Found shape {len(tens.shape)}. This function converts a Grayscale Tensor to its BGR counterpart'
+            f"Tensor of shape 2 expected. Found shape {len(tens.shape)}. "
+            "This function converts a Grayscale Tensor to its BGR counterpart"
         )
 
-    im = cv.cvtColor(tens, GRAY2BGR)
-    return to_tensor(im, cspace='bgr')
+    img = cv.cvtColor(tens, GRAY2BGR)
+    return to_tensor(img, cspace="bgr")
 
 
-def gray2hsv(tens) -> Tensor:
-    r'''
+def gray2hsv(tens: Tensor) -> Tensor:
+    r"""
         Converts a Grayscale Tensor to its HSV version.
 
     Args:
@@ -92,20 +94,21 @@ def gray2hsv(tens) -> Tensor:
     Raises:
         ValueError: If `tens` is not of shape 2
 
-    '''
+    """
     if not _is_gray_image(tens):
         raise ValueError(
-            f'Tensor of shape 2 expected. Found shape {len(tens.shape)}. This function converts a LAB Tensor to its HSV counterpart'
+            f"Tensor of shape 2 expected. Found shape {len(tens.shape)}. "
+            "This function converts a LAB Tensor to its HSV counterpart"
         )
 
     bgr = gray2bgr(tens)
 
-    im = bgr2hsv(bgr)
-    return to_tensor(im, cspace='hsv')
+    img = bgr2hsv(bgr)
+    return to_tensor(img, cspace="hsv")
 
 
-def gray2hls(tens) -> Tensor:
-    r'''
+def gray2hls(tens: Tensor) -> Tensor:
+    r"""
         Converts a Grayscale Tensor to its HLS version.
 
     Args:
@@ -117,20 +120,21 @@ def gray2hls(tens) -> Tensor:
     Raises:
         ValueError: If `tens` is not of shape 2
 
-    '''
+    """
     if not _is_gray_image(tens):
         raise ValueError(
-            f'Tensor of shape 2 expected. Found shape {len(tens.shape)}. This function converts a LAB Tensor to its HLS counterpart'
+            f"Tensor of shape 2 expected. Found shape {len(tens.shape)}. "
+            "This function converts a LAB Tensor to its HLS counterpart"
         )
 
     bgr = gray2bgr(tens)
 
-    im = bgr2hls(bgr)
-    return to_tensor(im, cspace='hls')
+    img = bgr2hls(bgr)
+    return to_tensor(img, cspace="hls")
 
 
-def gray2lab(tens) -> Tensor:
-    r'''
+def gray2lab(tens: Tensor) -> Tensor:
+    r"""
         Converts a Grayscale Tensor to its LAB version.
 
     Args:
@@ -142,20 +146,21 @@ def gray2lab(tens) -> Tensor:
     Raises:
         ValueError: If `tens` is not of shape 2
 
-    '''
+    """
     if not _is_gray_image(tens):
         raise ValueError(
-            f'Tensor of shape 2 expected. Found shape {len(tens.shape)}. This function converts a Grayscale Tensor to its LAB counterpart'
+            f"Tensor of shape 2 expected. Found shape {len(tens.shape)}. "
+            "This function converts a Grayscale Tensor to its LAB counterpart"
         )
 
     bgr = gray2bgr(tens)
 
-    im = bgr2lab(bgr)
-    return to_tensor(im, cspace='lab')
+    img = bgr2lab(bgr)
+    return to_tensor(img, cspace="lab")
 
 
-def gray2yuv(tens) -> Tensor:
-    r'''
+def gray2yuv(tens: Tensor) -> Tensor:
+    r"""
         Converts a Grayscale Tensor to its YUV version.
 
     Args:
@@ -167,20 +172,21 @@ def gray2yuv(tens) -> Tensor:
     Raises:
         ValueError: If `tens` is not of shape 2
 
-    '''
+    """
     if not _is_gray_image(tens):
         raise ValueError(
-            f'Tensor of shape 2 expected. Found shape {len(tens.shape)}. This function converts a Grayscale Tensor to its YUV counterpart'
+            f"Tensor of shape 2 expected. Found shape {len(tens.shape)}. "
+            "This function converts a Grayscale Tensor to its YUV counterpart"
         )
 
     bgr = gray2bgr(tens)
 
-    im = bgr2yuv(bgr)
-    return to_tensor(im, cspace='yuv')
+    img = bgr2yuv(bgr)
+    return to_tensor(img, cspace="yuv")
 
 
-def gray2luv(tens) -> Tensor:
-    r'''
+def gray2luv(tens: Tensor) -> Tensor:
+    r"""
         Converts a Grayscale Tensor to its LUV version.
 
     Args:
@@ -192,13 +198,14 @@ def gray2luv(tens) -> Tensor:
     Raises:
         ValueError: If `tens` is not of shape 2
 
-    '''
+    """
     if not _is_gray_image(tens):
         raise ValueError(
-            f'Tensor of shape 2 expected. Found shape {len(tens.shape)}. This function converts a Grayscale Tensor to its LUV counterpart'
+            f"Tensor of shape 2 expected. Found shape {len(tens.shape)}. "
+            "This function converts a Grayscale Tensor to its LUV counterpart"
         )
 
     bgr = gray2bgr(tens)
 
-    im = bgr2luv(bgr)
-    return to_tensor(im, cspace='luv')
+    img = bgr2luv(bgr)
+    return to_tensor(img, cspace="luv")
