@@ -18,24 +18,24 @@ from ._bgr import bgr2gray, bgr2lab, bgr2hsv, bgr2yuv, bgr2luv
 
 
 __all__ = [
-    'hls2rgb',
-    'hls2bgr',
-    'hls2lab',
-    'hls2gray',
-    'hls2hsv',
-    'hls2yuv',
-    'hls2luv',
+    "hls2rgb",
+    "hls2bgr",
+    "hls2lab",
+    "hls2gray",
+    "hls2hsv",
+    "hls2yuv",
+    "hls2luv",
 ]
 
 
-def _is_hls_image(tens):
-    # tens = to_tensor(tens)
+def _is_hls_image(tens: Tensor) -> bool:
+    # tens = to_tensor(tensg)
     # return tens.is_hls()
     return len(tens.shape) == 3 and tens.shape[-1] == 3
 
 
-def hls2rgb(tens) -> Tensor:
-    r'''
+def hls2rgb(tens: Tensor) -> Tensor:
+    r"""
         Converts a HLS Tensor to its RGB version.
 
     Args:
@@ -47,18 +47,19 @@ def hls2rgb(tens) -> Tensor:
     Raises:
         ValueError: If `tens` is not of shape 3
 
-    '''
+    """
     if not _is_hls_image(tens):
         raise ValueError(
-            f'Tensor of shape 3 expected. Found shape {len(tens.shape)}. This function converts a HLS Tensor to its RGB counterpart'
+            f"Tensor of shape 3 expected. Found shape {len(tens.shape)}. "
+            "This function converts a HLS Tensor to its RGB counterpart"
         )
 
-    im = cv.cvtColor(tens, HLS2RGB)
-    return to_tensor(im, cspace='rgb')
+    img = cv.cvtColor(tens, HLS2RGB)
+    return to_tensor(img, cspace="rgb")
 
 
-def hls2bgr(tens) -> Tensor:
-    r'''
+def hls2bgr(tens: Tensor) -> Tensor:
+    r"""
         Converts a HLS Tensor to its BGR version.
 
     Args:
@@ -70,18 +71,19 @@ def hls2bgr(tens) -> Tensor:
     Raises:
         ValueError: If `tens` is not of shape 3
 
-    '''
+    """
     if not _is_hls_image(tens):
         raise ValueError(
-            f'Tensor of shape 3 expected. Found shape {len(tens.shape)}. This function converts a HLS Tensor to its BGR counterpart'
+            f"Tensor of shape 3 expected. Found shape {len(tens.shape)}. "
+            "This function converts a HLS Tensor to its BGR counterpart"
         )
 
-    im = cv.cvtColor(tens, HLS2BGR)
-    return to_tensor(im, cspace='bgr')
+    img = cv.cvtColor(tens, HLS2BGR)
+    return to_tensor(img, cspace="bgr")
 
 
-def hls2gray(tens) -> Tensor:
-    r'''
+def hls2gray(tens: Tensor) -> Tensor:
+    r"""
         Converts a HLS Tensor to its Grayscale version.
 
     Args:
@@ -93,20 +95,21 @@ def hls2gray(tens) -> Tensor:
     Raises:
         ValueError: If `tens` is not of shape 3
 
-    '''
+    """
     if not _is_hls_image(tens):
         raise ValueError(
-            f'Tensor of shape 3 expected. Found shape {len(tens.shape)}. This function converts a HLS Tensor to its Grayscale counterpart'
+            f"Tensor of shape 3 expected. Found shape {len(tens.shape)}. "
+            "This function converts a HLS Tensor to its Grayscale counterpart"
         )
 
     bgr = hls2bgr(tens)
 
-    im = bgr2gray(bgr)
-    return to_tensor(im, cspace='gray')
+    img = bgr2gray(bgr)
+    return to_tensor(img, cspace="gray")
 
 
-def hls2hsv(tens) -> Tensor:
-    r'''
+def hls2hsv(tens: Tensor) -> Tensor:
+    r"""
         Converts a HLS Tensor to its HSV version.
 
     Args:
@@ -118,20 +121,21 @@ def hls2hsv(tens) -> Tensor:
     Raises:
         ValueError: If `tens` is not of shape 3
 
-    '''
+    """
     if not _is_hls_image(tens):
         raise ValueError(
-            f'Tensor of shape 3 expected. Found shape {len(tens.shape)}. This function converts a HLS Tensor to its LAB counterpart'
+            f"Tensor of shape 3 expected. Found shape {len(tens.shape)}. "
+            "This function converts a HLS Tensor to its LAB counterpart"
         )
 
     bgr = hls2bgr(tens)
 
-    im = bgr2hsv(bgr)
-    return to_tensor(im, cspace='hsv')
+    img = bgr2hsv(bgr)
+    return to_tensor(img, cspace="hsv")
 
 
-def hls2lab(tens) -> Tensor:
-    r'''
+def hls2lab(tens: Tensor) -> Tensor:
+    r"""
         Converts a HLS Tensor to its LAB version.
 
     Args:
@@ -143,20 +147,21 @@ def hls2lab(tens) -> Tensor:
     Raises:
         ValueError: If `tens` is not of shape 3
 
-    '''
+    """
     if not _is_hls_image(tens):
         raise ValueError(
-            f'Tensor of shape 3 expected. Found shape {len(tens.shape)}. This function converts a HLS Tensor to its LAB counterpart'
+            f"Tensor of shape 3 expected. Found shape {len(tens.shape)}. "
+            "This function converts a HLS Tensor to its LAB counterpart"
         )
 
     bgr = hls2bgr(tens)
 
-    im = bgr2lab(bgr)
-    return to_tensor(im, cspace='lab')
+    img = bgr2lab(bgr)
+    return to_tensor(img, cspace="lab")
 
 
-def hls2yuv(tens) -> Tensor:
-    r'''
+def hls2yuv(tens: Tensor) -> Tensor:
+    r"""
         Converts a HLS Tensor to its YUV version.
 
     Args:
@@ -168,20 +173,21 @@ def hls2yuv(tens) -> Tensor:
     Raises:
         ValueError: If `tens` is not of shape 3
 
-    '''
+    """
     if not _is_hls_image(tens):
         raise ValueError(
-            f'Tensor of shape 3 expected. Found shape {len(tens.shape)}. This function converts a HLS Tensor to its YUV counterpart'
+            f"Tensor of shape 3 expected. Found shape {len(tens.shape)}. "
+            "This function converts a HLS Tensor to its YUV counterpart"
         )
 
     bgr = hls2bgr(tens)
 
-    im = bgr2yuv(bgr)
-    return to_tensor(im, cspace='yuv')
+    img = bgr2yuv(bgr)
+    return to_tensor(img, cspace="yuv")
 
 
-def hls2luv(tens) -> Tensor:
-    r'''
+def hls2luv(tens: Tensor) -> Tensor:
+    r"""
         Converts a HLS Tensor to its LUV version.
 
     Args:
@@ -193,13 +199,14 @@ def hls2luv(tens) -> Tensor:
     Raises:
         ValueError: If `tens` is not of shape 3
 
-    '''
+    """
     if not _is_hls_image(tens):
         raise ValueError(
-            f'Tensor of shape 3 expected. Found shape {len(tens.shape)}. This function converts a HLS Tensor to its LUV counterpart'
+            f"Tensor of shape 3 expected. Found shape {len(tens.shape)}. "
+            "This function converts a HLS Tensor to its LUV counterpart"
         )
 
     bgr = hls2bgr(tens)
 
-    im = bgr2luv(bgr)
-    return to_tensor(im, cspace='luv')
+    img = bgr2luv(bgr)
+    return to_tensor(img, cspace="luv")
