@@ -12,23 +12,23 @@
 from ..io import imread 
 from ..path import abspath, join
 from .._base import __curr__ 
-from ..annotations import Optional
+from ..annotations import Optional, Tuple
 import numpy as np 
 
 from ..coreten import Tensor
 
-here = join(__curr__, 'data').replace('\\', "/") + "/"
+HERE = join(__curr__, 'data').replace('\\', "/") + "/"
 
 def _get_path_to_data(name) -> str:
-    return join(here, name)
+    return join(HERE, name)
 
 
-def audio_mixer(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def audio_mixer(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x427 image Tensor (RGB, by default) of an audio mixer.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -42,15 +42,15 @@ def audio_mixer(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor
         (427, 640, 3)
 
     """
-    return imread(here+'audio_mixer.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'audio_mixer.jpg', target_size=target_size, rgb=rgb)
 
 
-def bear(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def bear(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x427 image Tensor (RGB, by default) of a bear.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -64,15 +64,15 @@ def bear(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (427, 640, 3)
 
     """
-    return imread(here+'bear.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'bear.jpg', target_size=target_size, rgb=rgb)
 
 
-def beverages(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def beverages(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x427 image Tensor (RGB, by default) of beverages.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -86,15 +86,15 @@ def beverages(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (427, 640, 3)
         
     """
-    return imread(here+'beverages.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'beverages.jpg', target_size=target_size, rgb=rgb)
 
 
-def black_cat(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def black_cat(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x427 image Tensor (RGB, by default) of a black cat.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -108,15 +108,15 @@ def black_cat(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (427, 640, 3)
         
     """
-    return imread(here+'black_cat.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'black_cat.jpg', target_size=target_size, rgb=rgb)
 
 
-def blue_tang(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def blue_tang(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x414 image Tensor (RGB, by default) of a blue tang (a type of fish).
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -130,15 +130,15 @@ def blue_tang(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (414, 640, 3)
         
     """
-    return imread(here+'blue_tang.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'blue_tang.jpg', target_size=target_size, rgb=rgb)
 
 
-def camera(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def camera(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x427 image Tensor (RGB, by default) of a camera.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -152,15 +152,15 @@ def camera(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (427, 640, 3)
         
     """
-    return imread(here+'camera.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'camera.jpg', target_size=target_size, rgb=rgb)
 
 
-def controller(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def controller(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x427 image Tensor (RGB, by default) of a game controller.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -174,15 +174,15 @@ def controller(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (427, 640, 3)
         
     """
-    return imread(here+'controller.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'controller.jpg', target_size=target_size, rgb=rgb)
 
 
-def drone(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def drone(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x358 image Tensor (RGB, by default) of a robotic drone.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -196,15 +196,15 @@ def drone(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (358, 640, 3)
         
     """
-    return imread(here+'drone.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'drone.jpg', target_size=target_size, rgb=rgb)
 
 
-def dusk(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def dusk(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x427 image Tensor (RGB, by default) of a dusk landscape.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -218,15 +218,15 @@ def dusk(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (427, 640, 3)
         
     """
-    return imread(here+'dusk.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'dusk.jpg', target_size=target_size, rgb=rgb)
 
 
-def fighter_fish(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def fighter_fish(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x640 image Tensor (RGB, by default) of a fighter fish.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -240,15 +240,15 @@ def fighter_fish(target_size: Optional[tuple] = None, rgb: bool = True) -> Tenso
         (640, 640, 3)
         
     """
-    return imread(here+'fighter_fish.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'fighter_fish.jpg', target_size=target_size, rgb=rgb)
 
 
-def gold_fish(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def gold_fish(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x901 image Tensor (RGB, by default) of a gold fish.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -262,15 +262,15 @@ def gold_fish(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (901, 640, 3)
         
     """
-    return imread(here+'gold_fish.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'gold_fish.jpg', target_size=target_size, rgb=rgb)
 
 
-def green_controller(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def green_controller(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x512 image Tensor (RGB, by default) of a green game controller.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -284,15 +284,15 @@ def green_controller(target_size: Optional[tuple] = None, rgb: bool = True) -> T
         (512, 640, 3)
         
     """
-    return imread(here+'green_controller.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'green_controller.jpg', target_size=target_size, rgb=rgb)
 
 
-def green_fish(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def green_fish(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x430 image Tensor (RGB, by default) of a green fish.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -306,15 +306,15 @@ def green_fish(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (430, 640, 3)
         
     """
-    return imread(here+'green_fish.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'green_fish.jpg', target_size=target_size, rgb=rgb)
 
 
-def guitar(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def guitar(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x427 image Tensor (RGB, by default) of a guitar.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -328,15 +328,15 @@ def guitar(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (427, 640, 3)
         
     """
-    return imread(here+'guitar.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'guitar.jpg', target_size=target_size, rgb=rgb)
 
 
-def island(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def island(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x426 image Tensor (RGB, by default) of an island.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -350,15 +350,15 @@ def island(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (426, 640, 3)
         
     """
-    return imread(here+'island.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'island.jpg', target_size=target_size, rgb=rgb)
 
 
-def jellyfish(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def jellyfish(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x427 image Tensor (RGB, by default) of a jellyfish.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -372,15 +372,15 @@ def jellyfish(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (427, 640, 3)
         
     """
-    return imread(here+'jellyfish.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'jellyfish.jpg', target_size=target_size, rgb=rgb)
 
 
-def laptop(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def laptop(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x427 image Tensor (RGB, by default) of a laptop.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -394,15 +394,15 @@ def laptop(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (427, 640, 3)
         
     """
-    return imread(here+'laptop.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'laptop.jpg', target_size=target_size, rgb=rgb)
 
 
-def mountain(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def mountain(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x427 image Tensor (RGB, by default) of a mountain.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -416,15 +416,15 @@ def mountain(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (427, 640, 3)
         
     """
-    return imread(here+'mountain.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'mountain.jpg', target_size=target_size, rgb=rgb)
 
 
-def night(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def night(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x427 image Tensor (RGB, by default) of a night landscape.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -438,15 +438,15 @@ def night(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (427, 640, 3)
         
     """
-    return imread(here+'night.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'night.jpg', target_size=target_size, rgb=rgb)
 
 
-def puppies(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def puppies(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x427 image Tensor (RGB, by default) of a litter of puppies.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -460,15 +460,15 @@ def puppies(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (427, 640, 3)
         
     """
-    return imread(here+'puppies.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'puppies.jpg', target_size=target_size, rgb=rgb)
 
 
-def puppy(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def puppy(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x512 image Tensor (RGB, by default) of a puppy.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -482,15 +482,15 @@ def puppy(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (512, 640, 3)
         
     """
-    return imread(here+'puppy.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'puppy.jpg', target_size=target_size, rgb=rgb)
 
 
-def red_fish(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def red_fish(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x427 image Tensor (RGB, by default) of a red fish.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -504,15 +504,15 @@ def red_fish(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (427, 640, 3)
         
     """
-    return imread(here+'red_fish.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'red_fish.jpg', target_size=target_size, rgb=rgb)
 
 
-def phone(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def phone(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x427 image Tensor (RGB, by default) of a rotary phone.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -526,15 +526,15 @@ def phone(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (427, 640, 3)
         
     """
-    return imread(here+'rotary_phone.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'rotary_phone.jpg', target_size=target_size, rgb=rgb)
 
 
-def sea_turtle(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def sea_turtle(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x400 image Tensor (RGB, by default) of a sea turtle.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -548,15 +548,15 @@ def sea_turtle(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (400, 640, 3)
         
     """
-    return imread(here+'sea_turtle.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'sea_turtle.jpg', target_size=target_size, rgb=rgb)
 
 
-def snow(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def snow(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x360 image Tensor (RGB, by default) of snow.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -570,15 +570,15 @@ def snow(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (360, 640, 3)
         
     """
-    return imread(here+'snow.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'snow.jpg', target_size=target_size, rgb=rgb)
 
 
-def snowflake(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def snowflake(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x480 image Tensor (RGB, by default) of a snowflake.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -592,15 +592,15 @@ def snowflake(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (480, 640, 3)
         
     """
-    return imread(here+'snowflake.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'snowflake.jpg', target_size=target_size, rgb=rgb)
 
 
-def sunrise(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def sunrise(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x427 image Tensor (RGB, by default) of a sunrise landscape.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -614,15 +614,15 @@ def sunrise(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (427, 640, 3)
         
     """
-    return imread(here+'sunrise.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'sunrise.jpg', target_size=target_size, rgb=rgb)
 
 
-def tent(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
+def tent(target_size: Optional[Tuple[int, int]] = None, rgb: bool = True) -> Tensor:
     r"""
         Returns a standard 640x427 image Tensor (RGB, by default) of a tent.
 
     Args:
-        target_size (Optional[tuple]): Intended target size (follows the ``(width, height)`` format).
+        target_size (Optional[Tuple[int, int]]): Intended target size (follows the ``(width, height)`` format).
             If None, the unaltered tensor will be returned.
         rgb (bool): Boolean whether to return an RGB Tensor (default is ``True``).
     
@@ -636,7 +636,7 @@ def tent(target_size: Optional[tuple] = None, rgb: bool = True) -> Tensor:
         (427, 640, 3)
         
     """
-    return imread(here+'tent.jpg', target_size=target_size, rgb=rgb)
+    return imread(HERE+'tent.jpg', target_size=target_size, rgb=rgb)
 
 
 __all__ = [d for d in dir() if not d.startswith('_')]
