@@ -13,7 +13,6 @@
 #pylint:disable=undefined-all-variable
 
 from .paths import (
-    list_media,
     list_images,
     list_videos,
     listdir,
@@ -28,7 +27,7 @@ from .paths import (
     mkdir,
     osname,
     chdir,
-    minijoin,
+    join,
     dirname,
 
     # Variables
