@@ -19,25 +19,29 @@ from .io import imread
 from ._internal import _check_target_size
 from .path import join, list_images
 from .color import to_gray
+from .annotations import Optional,List,Tuple
 
 __all__ = [
-    'preprocess_from_dir',
-    'sep_train',
-    'normalize',
-    'train_val_split'
+    "preprocess_from_dir",
+    "sep_train",
+    "normalize",
+    "train_val_split"
 ]
 
 
-def preprocess_from_dir(DIR, 
-                        classes=None, 
-                        IMG_SIZE=None, 
-                        channels=3, 
-                        isShuffle=True, 
-                        save_data=False, 
-                        destination_filename=None, 
-                        verbose=True):
+def preprocess_from_dir(
+        DIR : str, 
+        classes : Optional[List[str]] = None, 
+        IMG_SIZE : Optional[Tuple[int,int]] = None, 
+        channels : int = 3, 
+        isShuffle : bool = True, 
+        save_data : bool = False, 
+        destination_filename : Optional[str] = None, 
+        verbose : bool = True
+    ):
     """
-    Reads Images in base directory DIR using 'classes' (computed from sub directories )
+    Reads Images in base directory DIR using ``classes`` (computed from sub directories)
+
     Arguments:
         DIR (str): Base directory 
         classes (list): A list of folder names within `DIR`.
@@ -45,7 +49,7 @@ def preprocess_from_dir(DIR,
         channels (int): Number of channels each image will be processed to (default: 3)
         isShuffle (bool): Shuffle the training set
         save_data (bool): If True, saves the training set as a .npy or .npz file based on destination_filename
-        destination_filename (str): if save_data is True, the train set will be saved as the filename specified
+        destination_filename (Optional[str]): if save_data is True, the train set will be saved as the filename specified
         verbose (bool): Displays the progress to the terminal as preprocessing continues. Default = True
     
     Returns
@@ -55,49 +59,49 @@ def preprocess_from_dir(DIR,
     data = [] 
 
     if not os.path.exists(DIR):
-        raise ValueError('The specified directory does not exist')
+        raise ValueError("The specified directory does not exist")
 
     if IMG_SIZE is None:
-        raise ValueError('IMG_SIZE must be specified')
+        raise ValueError("IMG_SIZE must be specified")
 
     if not isinstance(IMG_SIZE, tuple) or len(IMG_SIZE) != 2:
-        raise ValueError('IMG_SIZE must be a tuple of size 2 (width,height)')
+        raise ValueError("IMG_SIZE must be a tuple of size 2 (width,height)")
 
     if not isinstance(save_data, bool):
-        raise ValueError('save_data must be a boolean (True/False)')
+        raise ValueError("save_data must be a boolean (True/False)")
 
     if not isinstance(classes, list):
-        raise ValueError('"classes" must be a list')
+        raise ValueError("`classes` must be a list")
 
     if save_data:
         if destination_filename is None:
-            raise ValueError('Specify a destination file name')
+            raise ValueError("Specify a destination file name")
 
-        elif not ('.npy' in destination_filename or '.npz' in destination_filename):
-            raise ValueError('Specify the correct numpy destination file extension (.npy or .npz)')
+        elif not (".npy" in destination_filename or ".npz" in destination_filename):
+            raise ValueError("Specify the correct numpy destination file extension (.npy or .npz)")
     
     if not save_data and destination_filename is not None:
         destination_filename = None
 
     # Loading from Numpy Files
     if destination_filename is not None and os.path.exists(destination_filename):
-        print('[INFO] Loading from Numpy Files')
+        print("[INFO] Loading from Numpy Files")
         since = time.time()
         data = np.load(destination_filename, allow_pickle=True)
         end = time.time()
         took = end - since
-        print('----------------------------------------------')
-        print(f'[INFO] Loaded in {took:.0f}s from Numpy Files')
+        print("----------------------------------------------")
+        print(f"[INFO] Loaded in {took:.0f}s from Numpy Files")
 
         return data
 
     # Extracting image data and adding to `data`
     else:
         if destination_filename is not None:
-            print(f'[INFO] Could not find {destination_filename}. Generating the training data')
+            print(f"[INFO] Could not find {destination_filename}. Generating the training data")
         else:
-            print('[INFO] Could not find a file to load from. Generating the training data')
-        print('----------------------------------------------')
+            print("[INFO] Could not find a file to load from. Generating the training data")
+        print("----------------------------------------------")
 
         # Starting timer
         since_preprocess = time.time()
@@ -132,10 +136,10 @@ def preprocess_from_dir(DIR,
         # Saves the Data set as a .npy file
         if save_data:
             #Converts to Numpy and saves
-            if destination_filename.endswith('.npy'):
-                print('[INFO] Saving as .npy file')
-            elif destination_filename.endswith('.npz'):
-                print('[INFO] Saving as .npz file')
+            if destination_filename.endswith(".npy"):   # type: ignore
+                print("[INFO] Saving as .npy file")
+            elif destination_filename.endswith(".npz"): # type: ignore
+                print("[INFO] Saving as .npz file")
             
             # Saving
             since = time.time()
@@ -145,7 +149,7 @@ def preprocess_from_dir(DIR,
             time_elapsed = end-since
             minu_elapsed = time_elapsed // 60
             sec_elapsed = time_elapsed % 60
-            print(f'[INFO] {destination_filename} saved! Took {minu_elapsed:.0f}m {sec_elapsed:.0f}s')
+            print(f"[INFO] {destination_filename} saved! Took {minu_elapsed:.0f}m {sec_elapsed:.0f}s")
 
         #Returns Training Set
         end_preprocess = time.time()
@@ -153,12 +157,12 @@ def preprocess_from_dir(DIR,
         minu = time_elapsed_preprocess // 60
         sec = time_elapsed_preprocess % 60
 
-        print('----------------------------------------------')
-        print(f'[INFO] {len(data)} files preprocessed! Took {minu:.0f}m {sec:.0f}s')
+        print("----------------------------------------------")
+        print(f"[INFO] {len(data)} files preprocessed! Took {minu:.0f}m {sec:.0f}s")
 
         return data
 
-def normalize(x, dtype='float32'):
+def normalize(x, dtype="float32"):
     """
     Normalizes the data to mean 0 and standard deviation 1
     """
@@ -169,14 +173,14 @@ def normalize(x, dtype='float32'):
     x = x.astype(dtype) / 255
     return x
 
-def sep_train(data, IMG_SIZE, channels=1):
+def sep_train(data, IMG_SIZE:Tuple[int,int], channels:int=1):
     # x = []
     # y = []
     # for feature, label in data:
     #     x.append(feature)
     #     y.append(label)
     
-    _ = _check_target_size(IMG_SIZE)
+    _check_target_size(IMG_SIZE)
 
     x = [i[0] for i in data]
     y = [i[1] for i in data]
@@ -191,8 +195,8 @@ def sep_train(data, IMG_SIZE, channels=1):
     return x, y
 
 
-def reshape(x, IMG_SIZE, channels):
-    _ = _check_target_size(IMG_SIZE)
+def reshape(x, IMG_SIZE:Tuple[int,int], channels:int):
+    _check_target_size(IMG_SIZE)
 
     width, height = IMG_SIZE[:2]
     return np.array(x).reshape(-1, width, height, channels)
\ No newline at end of file
