@@ -13,37 +13,31 @@ import cv2 as cv
 import numpy as np 
 
 from ..coreten import Tensor
-from .position import _proc_in_chunks
-
 
 __all__ = [
-    'blur',
-    'gaussian_blur',
-    'median_blur',
-    'motion_blur'
+    "blur",
+    "gaussian_blur",
+    "median_blur",
+    "motion_blur"
 ]
 
-def blur(tens, ksize) -> Tensor:
-    func = _proc_in_chunks(cv.blur, ksize=(ksize, ksize))
-    return func(tens)
+def blur(tens: Tensor, ksize:int) -> Tensor:
+    return cv.blur(tens, ksize=(ksize, ksize))
 
 
-def gaussian_blur(tens, ksize, sigma=0) -> Tensor:
+def gaussian_blur(tens: Tensor, ksize:int, sigma=0) -> Tensor:
     # When sigma=0, it is computed as `sigma = 0.3*((ksize-1)*0.5 - 1) + 0.8`
-    func = _proc_in_chunks(cv.GaussianBlur, ksize=(ksize, ksize), sigmaX=sigma)
-    return func(tens)
+    return cv.GaussianBlur(tens, ksize=(ksize, ksize), sigmaX=sigma)
 
 
-def median_blur(tens, ksize) -> Tensor:
+def median_blur(tens: Tensor, ksize:int) -> Tensor:
     if tens.dtype == np.float32 and ksize not in {3, 5}:
         raise ValueError(
             "Invalid ksize value {}. For a float32 image the only valid ksize values are 3 and 5".format(ksize)
         )
 
-    func = _proc_in_chunks(cv.medianBlur, ksize=ksize)
-    return func(tens)
+    return cv.medianBlur(tens, ksize=ksize)
 
 
-def motion_blur(tens, kernel) -> Tensor:
-    func = _proc_in_chunks(cv.filter2D, ddepth=-1, kernel=kernel)
-    return func(tens)
\ No newline at end of file
+def motion_blur(tens: Tensor, kernel) -> Tensor:
+    return cv.filter2D(tens, ddepth=-1, kernel=kernel)
\ No newline at end of file
