@@ -20,17 +20,16 @@ import numpy as np
 from .constants import (
     FPS, FRAME_COUNT, FRAME_HEIGHT, FRAME_WIDTH
 )
-from ..annotations import Tuple
+from ..annotations import Tuple, Optional
 from ..coreten import Tensor
 
 __all__ = [
-    'Stream'
+    "Stream"
 ]
 
-
 #pylint:disable=no-member
 
-# ret, jpeg = cv2.imencode('.jpg', image)
+# ret, jpeg = cv2.imencode(".jpg", image)
 # return jpeg.tobytes()
 
 # This class can handle both live as well as pre-existing videos. 
@@ -54,10 +53,10 @@ class Stream:
         
         if isinstance(source, int):
             self.live_video = True
-            # raise ValueError('Expected a filepath. Got an integer. FileVideoStream is not for live feed. Use LiveVideoStream instead')
+            # raise ValueError("Expected a filepath. Got an integer. FileVideoStream is not for live feed. Use LiveVideoStream instead"ConnectionRefusedError())
 
         if not isinstance(source, (int,str)):
-            raise ValueError(f'Expected either an integer or filepath. Got {type(source)}')
+            raise ValueError(f"Expected either an integer or filepath. Got {type(source)}")
         
         # initializing the video stream
         self._video_stream = cv.VideoCapture(source)
@@ -71,13 +70,13 @@ class Stream:
         self.frames = int(self._video_stream.get(FRAME_COUNT))
         
         # initialize the queue to store frames 
-        self._Q = Queue(maxsize=qsize)
+        self._Q: Queue = Queue(maxsize=qsize)
 
         # intialize thread
-        self._thread = None
+        self._thread: Optional[Thread] = None
 
 
-    def start(self) -> None:
+    def start(self):
         # start a thread to read frames from the video stream
         self._thread = Thread(target=self._update, name="caer.video.Stream()", args=())
         self._thread.daemon = True
@@ -85,7 +84,7 @@ class Stream:
         return self
 
 
-    def _update(self) -> Tensor:
+    def _update(self):
         while True:
             if self.kill_stream:
                 break
@@ -126,60 +125,56 @@ class Stream:
         # wait until stream resources are released
         if self._thread is not None:
             self._thread.join()
-            self._thread = None 
+            self._thread = None
         self.frames = 0 
         self.fps = 0
     
 
     # Gets frame count
-    def count_frames(self) -> int:
+    def count_frames(self) -> int: # type: ignore[return]
         """
             Returns the number of frames for the current video
             Optional: use the `frames` attribute
         """
         if not self.kill_stream and not self.live_video:
             return self.frames
-            # if get_opencv_version() == '2':
+            # if get_opencv_version() == "2":
             #     return int(self.stream.get(FRAME_COUNT_DEPR))
             # else:
             #     return int(self.stream.get(FRAME_COUNT))
             
 
         if self.live_video:
-            print('[WARNING] Frames cannot be computed on live streams')
+            print("[WARNING] Frames cannot be computed on live streams")
             return -1
 
 
     # Gets FPS count
-    def get_fps(self) -> (float, int):
+    def get_fps(self) -> int: # type: ignore[return]
         """
             Returns the fps (frames per second) value for the current video
             Optional: use the `fps` attribute
         """
         if not self.kill_stream:
             return self.fps
-            # if get_opencv_version() == '2':
-            #     return math.ceil(self.stream.get(FPS_DEPR))
-            # else:
-            #     return math.ceil(self.stream.get(FPS))
     
     
     # Get frame dimensions
-    def get_res(self) -> Tuple[int]:
+    def get_res(self) -> Tuple[int, int]:
         return self.res
 
 
 
 ###########################################################################################
-# Old implementation of stream.py when it used to inherit the FileStream() from filestream.py
-# Until 5 Dec 2020, this was the implementation
+# Old implementation of stream.py when it used to inherit the FileStream() from filestream.py.
+# Until 5 Dec 2020, this was the implementation.
 ###########################################################################################
 
 # from .filestream import FileStream
 
 
 # __all__ = [
-#     'Stream'
+#     "Stream"
 # ]
 
 # # Using the FileStream class as it can handle both live as well as pre-existing videos
@@ -192,9 +187,7 @@ class Stream:
 
 #     def __init__(self, source=0):
 #         # Initializing the stream from DefaultVideoStream
-#         print('Beg of f')
 #         self._video_stream = FileStream(source=source)
-#         print('End of f')
 
 #         self.width = self._video_stream.width
 #         self.height = self._video_stream.height
